#
# Makefile Template for Tessy
# Compiler: Freescale MPC55XX
# Debugger: LAUTERBACH TRACE32
# Template Version: 2
#

# Defines to be generated by Tessy:
#
# BUFFER_SIZE           :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# ENDIANESS             :=
# EXEFILE_EXTENSION     :=
# LINKER_FILE           :=
# MODULE_PATH           :=
# MODULE_PATH_DOS       :=
# OBJFILE_EXTENSION     :=
# PROJECTROOT           :=
# TARGET_INSTALL_PATH   :=
# TESSY_BIN             :=
# TESSY_SYS             :=
# TESTOBJECT            :=
# TIMER_FILE            :=
# TARGET_INSTALL_PATH   :=
# TIMER_FILE            :=
# USER_LINK_OPTIONS     :=

#####################################################################
#BEGIN_DEFINES
#####################################################################

#
# Special macros for includes and defines
#
TS_DEF_SEPARATOR :=-D
define TS_DEFINE
$(subst ;, $(TS_DEF_SEPARATOR),$(1))
endef

TS_INC_SEPARATOR :=-I
define TS_INCLUDE
$(subst ;, $(TS_INC_SEPARATOR),$(1))
endef

TESSY_SYS_DOS   := $(shell ts_pathname -s $(TESSY_SYS))
METROWERKS_HOME := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')
LINK_FILE_SHORT := $(shell ts_pathname -s '$(LINKER_FILE)')

ifneq ($(InitSrcDir),)
INITOBJDIR      := $(shell ts_pathname -s -m $(InitObjDir))
INITSRCDIR      := $(shell ts_pathname -s -m $(InitSrcDir))
endif

TS_NAME         := TS_TRACE32
IDE_NAME        := trace32
COMPANY_NAME    := metrowerks
PROCESSOR_NAME  := mpc55xx

ifeq ("little","$(ENDIANESS)")
  TS_BYTEORDER := TS_HOST_BYTEORDER
  TS_BYTEORDER_OPTION :=
  TS_BYTEORDER_LOPTION :=
endif
ifeq ("big","$(ENDIANESS)")
  TS_BYTEORDER := TS_NET_BYTEORDER
  TS_BYTEORDER_OPTION :=
  TS_BYTEORDER_LOPTION :=
endif
ifndef TS_BYTEORDER
  $(error Attribute 'Endianess' has invalid value '$(ENDIANESS)', only 'little' and 'big' are allowed.)
endif

all	 : master slave
master : $(MODULE_PATH)/ts_$(TESTOBJECT)_m.exe
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION)


#
#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE := $(TESSY_SYS)/make/master_$(IDE_NAME)_gnu_i386.mk
S_COMM_MAKE := $(TESSY_SYS)/src/comm/comm_$(IDE_NAME)_$(COMPANY_NAME)_$(PROCESSOR_NAME).mk



#
#
# SLAVE
#
S_CC           := $(METROWERKS_HOME)\PowerPC_EABI_Tools\Command_Line_Tools\mwcceppc.exe
S_LINK         := $(METROWERKS_HOME)\PowerPC_EABI_Tools\command_line_tools\mwldeppc.exe
S_INCLUDES     := -c -ir $(METROWERKS_HOME)\PowerPC_EABI_Support \
			-I$(TESSY_SYS_DOS)\include\tessy\comm -I$(MODULE_PATH_DOS)
S_STUB_OBJECT  := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs$(OBJFILE_EXTENSION)
S_UC_OBJECT    := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr$(OBJFILE_EXTENSION)
S_COMP_OPTIONS := -opt off  -MD -abi=eabi -ppc_asm_to_vle -vle -proc=5565 -fp=soft -use_isel=on	-sdata=0 -sdata2=0 \
			-DTESSY -DTS_SLAVE -D$(TS_NAME) -DTS_HAVE_INT64 -DTS_HAVE_FLOAT64
S_LINK_OPTIONS := -gdwarf-2 -L$(METROWERKS_HOME)\PowerPC_EABI_Support\Runtime\Lib \
			-L$(METROWERKS_HOME)\PowerPC_EABI_Support\MSL\MSL_C\PPC_EABI\Lib \
			-lRuntime.PPCEABI.VS.a -lMSL_C.PPCEABI.bare.VS.a

#####################################################################
#END_DEFINES
#####################################################################

#####################################################################
#BEGIN_SOURCE
#####################################################################

#
# Template rules
#
$(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER)$(OBJFILE_EXTENSION): $(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER).c
	$(S_CC) $(S_INCLUDES) $(call TS_INCLUDE,$(USER_INCLUDES$$(SOURCENUMBER))) $(S_COMP_OPTIONS) \
		$(call TS_DEFINE,$(USER_DEFINES$$(SOURCENUMBER))$(S_COM_OPTIONS)) \
		$(USER_COMP_OPTIONS$$(SOURCENUMBER)) -o "$@" "$<"


#####################################################################
#END_SOURCE
#####################################################################

#####################################################################
#BEGIN_TARGETS
#####################################################################

# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -o "$@" $<

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -o "$@" $<


#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)


#
#
# COMPILE/LINK SLAVE
#

$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	@echo ***** Compiling Slave *****
	$(S_CC) $(S_COMP_OPTIONS) $(S_INCLUDES) -o $@ $<

ifeq ("true","$(USE_BOARD_FILES)")
MPC55XX_OBJS := $(patsubst $(INITSRCDIR)/%.c,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.c)) \
                $(patsubst $(INITSRCDIR)/%.asm,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.asm))

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.c
	$(S_CC) -I$(INITSRCDIR) $(S_COMP_OPTIONS) -I- $(S_INCLUDES) -o $@ $<

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.asm
	$(S_CC) -I$(INITSRCDIR) $(S_COMP_OPTIONS) -I- $(S_INCLUDES) -o $@ $<
endif

$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
																			$(S_SRC_OBJECTS) \
																			$(MPC55XX_OBJS) \
																			$(S_UC_OBJECT) \
																			$(S_STUB_OBJECT) \
																			$(S_OBJECTS)
	@echo *
	@echo ***** Linking Slave *****
	$(S_LINK) $(S_LINK_OPTIONS) $(USER_LINK_OPTIONS) \
						$(S_OBJECTS) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
						$(S_SRC_OBJECTS) $(MPC55XX_OBJS) $(S_UC_OBJECT) $(S_STUB_OBJECT) \
						-o "$@" -lcf $(LINK_FILE_SHORT)
	@-ts_rm "$(MODULE_PATH)"/*$(OBJFILE_EXTENSION)

#####################################################################
#END_TARGETS
#####################################################################

#
# Command line:
# "C:\Program Files\Freescale\CodeWarrior for MPC55xx V2.3\pemicro\cw_icdppcnexus.exe" ts_is_value_in_range_s.elf LOADTORAM -RESETFILE "mpc5516_booke.mac"
#
